function q_new = kinematicMotionControl(tf,ts,k,q_current,r_traj)
    % Inputs:
    %  tf         : total simulation time.
    %  ts         : simulation time-step.
    %  k          : current iteration.
    %  q_current  : current configuration of the robot
    % Output: joint-space state of the robot to send to the visualization.

    % Total number of iterations
    Nf = tf/ts;
    K_p = 1.0;
    
    % Step 1. - Compute the next point in the Cartesian trajectory of the
    % end-effector
    r_new = r_traj(k,:).';
    
    % Step 2. - Update step  
    r_current = jointToPosition(q_current);
    J_current = jointToPosJac(q_current);
    w_new = K_p*(r_new - r_current);
    Dq = J_current\w_new;

    % Step Y. - Time integration step - this is would be used for a position
    % controllable robot
    q_new = q_current + Dq*ts;
  
end
