% Motor control visualization script

% Close all figures
close all; clear;

% Load the visualization
loadVisualization;

% Set the sampling time (in seconds)
ts = 0.05;

% Configure a new trajectory - use defaults if undefined
if ~exist('r_start','var')
    r_start = [0.3740 0 0.6300].';
end
if ~exist('r_end','var')
    r_end = [0.5 0.5 0.3].';
end
if ~exist('tf','var')
    tf = 5.0;
end
if ~exist('q_0','var')
    q_0 = zeros(6,1);
end

% Generate a new desired trajectory
r_traj = generateLineTrajectory(r_start, r_end, tf, ts); 

% Initialize the vector of generalized coordinates
q = q_0;

% Set the number of time steps
kf = tf/ts; % Number of iterations as a function of the duration and the sampling time

% Notify that the visualization loop is starting
disp('Starting visualization loop.');

% Run a visualization loop
for k=1:kf
    %try
        % Start a timer
        startLoop = tic;
        % Set the updated vector of generalized coordinates.
        q = kinematicMotionControl(tf,ts,k,q,r_traj);
        % Set the generalized coordinates to the robot visualizer class
        abbRobot.setJointPositions(q);
        % Update the visualization figure
        drawnow;
        % If enough time is left, wait to try to keep the update frequency
        % stable
        residualWaitTime = ts - toc(startLoop);
        if (residualWaitTime > 0)
            pause(residualWaitTime);
        end
    %catch
        %disp('Exiting the visualization loop.');
        %break;
    %end
end

% Notify the user that the script has ended.
disp('Visualization loop has ended.');
